==> ns-jckj-api-2.0.0-20250716.032109-11.jar: db/migration/V1.0.12__增加游客模式.sql <==
--游客用户
INSERT INTO sys_user
(f_id, f_name, f_aname, f_bh, f_tel, f_worktel, f_email, f_zhiwu, f_ganwei, f_zhiji, f_zhicheng, f_sex, f_worktype, f_address, f_status, f_createtime, f_updatetime, f_params, f_userlevel, f_source, f_imgid, f_tel_encrypt, f_kind, f_certificate_code, f_tenantid, f_creatorid, f_accout, f_type)
VALUES('guest', 'guest', 'guest', '', '130****0000', '', '', '', '', '', '', 0, '', '', 1, '2025-06-20 07:59:50.428', NULL, NULL, 3, '10000', '', '+4EarroKcRZWtnRh0uGVdg==', 1, NULL, '0', '1', NULL, NULL);
--角色
INSERT INTO sys_role
(f_id, f_name, f_key, f_level, f_pid, f_type, f_allname, f_sort, f_createtime, f_creatorid, f_bz, f_tenantid)
VALUES('1083071854110834688', '免登入游客角色', NULL, '1', '0', 0, '免登入游客角色', 24, '2025-06-20 08:01:17.309', '1', '', '0');
INSERT INTO sys_role
(f_id, f_name, f_key, f_level, f_pid, f_type, f_allname, f_sort, f_createtime, f_creatorid, f_bz, f_tenantid)
VALUES('guest', '游客角色', NULL, '2', '1083071854110834688', 1, '游客角色', 1, '2025-06-20 08:01:38.471', '1', '', '0');
--组织机构
INSERT INTO sys_organization
(f_id, f_name, f_aname, f_code, f_level, f_pid, f_sort, f_leader, f_bz, f_tenantid, f_creatorid, f_id_path, f_source)
VALUES('1083071573511897088', '未知机构', '', '', 1, '0', 5, NULL, '', '0', '1', '1083071573511897088', 10000);
--用户与角色关系
INSERT INTO sys_user_role
(f_id, f_userid, f_roleid)
VALUES('1083072121053118464', 'guest', 'guest');
--用户与组织机构关系
INSERT INTO sys_user_organization
(f_id, f_userid, f_orgid, f_role, f_rank)
VALUES('1083071628490833920', 'guest', '1083071573511897088', 1, 1);

==> ns-jckj-api-2.0.0-20251021.063713-24.jar: db/migration/V1.0.12__增加游客模式.sql <==
--游客用户
delete from sys_user where f_id='guest';
INSERT INTO sys_user
(f_id, f_name, f_aname, f_bh, f_tel, f_worktel, f_email, f_zhiwu, f_ganwei, f_zhiji, f_zhicheng, f_sex, f_worktype, f_address, f_status, f_createtime, f_updatetime, f_params, f_userlevel, f_source, f_imgid, f_tel_encrypt, f_kind, f_certificate_code, f_tenantid, f_creatorid, f_accout, f_type)
VALUES('guest', 'guest', 'guest', '', '130****0000', '', '', '', '', '', '', 0, '', '', 1, '2025-06-20 07:59:50.428', NULL, NULL, 3, '10000', '', '+4EarroKcRZWtnRh0uGVdg==', 1, NULL, '0', '1', NULL, NULL);
--角色
delete from sys_role where f_id='1083071854110834688';
delete from sys_role where f_id='guest';
INSERT INTO sys_role
(f_id, f_name, f_key, f_level, f_pid, f_type, f_allname, f_sort, f_createtime, f_creatorid, f_bz, f_tenantid)
VALUES('1083071854110834688', '免登入游客角色', NULL, '1', '0', 0, '免登入游客角色', 24, '2025-06-20 08:01:17.309', '1', '', '0');
INSERT INTO sys_role
(f_id, f_name, f_key, f_level, f_pid, f_type, f_allname, f_sort, f_createtime, f_creatorid, f_bz, f_tenantid)
VALUES('guest', '游客角色', NULL, '2', '1083071854110834688', 1, '游客角色', 1, '2025-06-20 08:01:38.471', '1', '', '0');
--组织机构
delete from sys_organization where f_id='1083071573511897088';
INSERT INTO sys_organization
(f_id, f_name, f_aname, f_code, f_level, f_pid, f_sort, f_leader, f_bz, f_tenantid, f_creatorid, f_id_path, f_source)
VALUES('1083071573511897088', '未知机构', '', '', 1, '0', 5, NULL, '', '0', '1', '1083071573511897088', 10000);
--用户与角色关系
delete from sys_user_role where f_id='1083072121053118464';
INSERT INTO sys_user_role
(f_id, f_userid, f_roleid)
VALUES('1083072121053118464', 'guest', 'guest');
--用户与组织机构关系
delete from sys_user_organization where f_id='1083071628490833920';
INSERT INTO sys_user_organization
(f_id, f_userid, f_orgid, f_role, f_rank)
VALUES('1083071628490833920', 'guest', '1083071573511897088', 1, 1);
